@@ -8,7 +8,7 @@ package Lemonldap::NG::Common::Conf::Attributes;
 
 use Mouse;
 
-our $VERSION = 1.4.1;
+our $VERSION = 1.4.11;
 
 ## A
 
@@ -19,6 +19,20 @@ has 'activeTimer' => (
     documentation => 'Enable timers on portal pages',
 );
 
+has 'ADPwdExpireWarning' => (
+    is            => 'rw',
+    isa           => 'Int',
+    default       => '0',
+    documentation => 'AD password expire warning',
+);
+
+has 'ADPwdMaxAge' => (
+    is            => 'rw',
+    isa           => 'Int',
+    default       => '0',
+    documentation => 'AD password max age',
+);
+
 has 'apacheAuthnLevel' => (
     is            => 'rw',
     isa           => 'Int',
@@ -1429,6 +1443,13 @@ has 'timeoutActivity' => (
     documentation => 'Session activity timeout on server side',
 );
 
+has 'timeoutActivityInterval' => (
+    is            => 'rw',
+    isa           => 'Int',
+    default       => '60',
+    documentation => 'Update session timeout interval on server side',
+);
+
 has 'trustedProxies' => (
     is            => 'rw',
     isa           => 'Str',
