@@ -8,7 +8,7 @@ package Lemonldap::NG::Common::Conf::SubAttributes;
 
 use Mouse;
 
-our $VERSION = 1.4.1;
+our $VERSION = 1.4.11;
 
 ## E
 
@@ -165,6 +165,13 @@ has 'samlIDPMetaDataOptionsSignSSOMessage' => (
     documentation => 'SAML IDP option sign SSO',
 );
 
+has 'samlIDPMetaDataOptionsStoreSAMLToken' => (
+    is            => 'rw',
+    isa           => 'Bool',
+    default       => '0',
+    documentation => 'SAML IDP option store SAML token',
+);
+
 has 'samlSPMetaDataExportedAttributes' => (
     is            => 'rw',
     isa           => 'HashRef',
